use crate::configdata::*;
use crate::systemdata::*;
use crate::clap_ps::ForceFrom;

use color_eyre::eyre::Result;

pub enum CurrentScreen {
    Dash,
    Configuration,
    Exit,
}

pub enum ConfigEdit {
    PkKey,
    SpKey,
    AvatarEnabled,
    AvatarFolder,
    AvatarOutput,
    AvatarBlacklist,
    DiscEnabled,
    DiscToken,
    FediEnabled,
    FediInstance,
    FediToken,
}

pub struct App {
    pub input: String,
    pub cfg_dir: String,
    pub cfg: Option<Config>,
    pub sys: Option<System>,
    pub fronters: Option<Fronters>,
    pub current_screen: Option<CurrentScreen>,
    pub editing: Option<ConfigEdit>,
}

impl App {
    pub fn new(confpath: String) -> App {
        App {
            input: String::new(),
            cfg_dir: confpath,
            cfg: None,
            sys: None,
            fronters: None,
            current_screen: None,
            editing: None,
        }
    }

    pub fn load_system(&mut self, update: bool) -> Result<()> {

        match System::get_system(&self, update) {
            Ok(s) => {
                self.sys = Some(s);
                Ok(())
            },
            Err(e) => {
                self.sys = None;
                Err(e)
            }
        }
    }

    pub fn load_config(&mut self) -> Result<()> {

        match Config::get_config(&self.cfg_dir) {
            Ok(c) => {
                self.cfg = Some(c);
                Ok(())
            },
            Err(e) => {
                self.cfg = None;
                Err(e)
            },
        }

    }

    pub fn get_fronters(&mut self, ff: ForceFrom) -> Result<()> {

        self.fronters = Some(Fronters::get(self, ff)?);

        Ok(())
    }

    pub fn set_fronters(&mut self, to_front: Vec<Member>) -> Result<()> {

        self.get_fronters(ForceFrom::None)?;

        self.fronters = Some(Fronters::set(self, to_front)?);

        Ok(())
    }
}
